@@ -16,7 +16,7 @@ checkfail()
 # ARGUMENTS #
 #############
 
-MEDIALIBRARY_HASH=e7cd5d7f
+MEDIALIBRARY_HASH=3b10e82
 
 RELEASE=0
 ASAN=0
@@ -104,6 +104,7 @@ VLC_BOOTSTRAP_ARGS="\
     --disable-vncclient \
     --disable-vnc \
     --enable-jpeg \
+    --enable-ad-clauses \
 "
 
 ###########################
@@ -840,11 +841,15 @@ if [ ! -d "build-android-$ANDROID_ABI/" ]; then
 fi;
 cd "build-android-$ANDROID_ABI/";
 
+if [ "$RELEASE" = 1 ]; then
+    MEDIALIBRARY_MODE=--enable-release
+fi
 if [ ! -e ./config.h -o "$RELEASE" = 1 ]; then
 ../bootstrap
 ../configure \
     --host=$TARGET_TUPLE \
     --disable-shared \
+    ${MEDIALIBRARY_MODE} \
     CFLAGS="${VLC_CFLAGS} ${EXTRA_CFLAGS}" \
     CXXFLAGS="${VLC_CXXFLAGS} ${EXTRA_CFLAGS} ${EXTRA_CXXFLAGS}" \
     CC="clang" \
