@@ -627,7 +627,6 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                         mWakeLock.release();
                     break;
                 case MediaPlayer.Event.Stopped:
-                    mMedialibrary.resumeBackgroundOperations();
                     Log.i(TAG, "MediaPlayer.Event.Stopped");
                     onPlaybackStopped();
                     break;
@@ -682,6 +681,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
     private void onPlaybackStopped() {
         if (mStopped)
             return;
+        mMedialibrary.resumeBackgroundOperations();
         mStopped = true;
         mCurrentIndex = -1;
         hideNotification();
@@ -705,8 +705,9 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         if (canSwitchToVideo || media.isPodcast()) {
             //Save progress
             final long time = getTime();
-            float progress = time / (float)media.getLength();
-            if (progress > 0.95f) {
+            final long length =  media.getLength();
+            float progress = time / (float)length;
+            if (progress > 0.95f || (length-time) < 10000) {
                 //increase seen counter if more than 95% of the media have been seen
                 //and reset progress to 0
                 final long incSeen = media.getSeen() + 1L;
@@ -1990,7 +1991,9 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         mMediaPlayer.setMedia(media);
         media.release();
 
-        if (mw .getType() != MediaWrapper.TYPE_VIDEO || isVideoPlaying || mw.hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO)) {
+        if (mw.hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO) && mMediaPlayer.getAudioTracksCount() == 0)
+            next();
+        else if (mw .getType() != MediaWrapper.TYPE_VIDEO || isVideoPlaying || mw.hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO)) {
             mMediaPlayer.setEqualizer(VLCOptions.getEqualizerSetFromSettings(this));
             mMediaPlayer.setVideoTitleDisplay(MediaPlayer.Position.Disable, 0);
             changeAudioFocus(true);
