@@ -131,24 +131,24 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
             final FragmentManager fm = getSupportFragmentManager();
             mCurrentFragment = fm.getFragment(savedInstanceState, "current_fragment");
             //Restore fragments stack
-            final List<Fragment> fragments = fm.getFragments();
-            if (fragments != null) {
-                final FragmentTransaction ft =  fm.beginTransaction();
-                for (Fragment fragment : fragments)
-                    if (fragment != null) {
-                        if (fragment instanceof ExtensionBrowser) {
-                            ft.remove(fragment);
-                        } else if ((fragment instanceof MediaBrowserFragment)) {
-                            mFragmentsStack.put(fragment.getTag(), new WeakReference<>(fragment));
-                            if (fragment != mCurrentFragment)
-                                ft.hide(fragment);
-                        }
-                    }
-                ft.commit();
-            }
+            restoreFragmentsStack(savedInstanceState, fm);
             mCurrentFragmentId = savedInstanceState.getInt("current", mSettings.getInt("fragment_id", R.id.nav_video));
-        } else
+        } else {
+            if (getIntent().getBooleanExtra(StartActivity.EXTRA_UPGRADE, false)) {
+            /*
+             * The sliding menu is automatically opened when the user closes
+             * the info dialog. If (for any reason) the dialog is not shown,
+             * open the menu after a short delay.
+             */
+            mActivityHandler.postDelayed(new Runnable() {
+                    @Override
+                    public void run() {
+                        mDrawerLayout.openDrawer(mNavigationView);
+                    }
+                }, 500);
+            }
             reloadPreferences();
+        }
 
         /* Set up the action bar */
         prepareActionBar();
@@ -159,8 +159,9 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
             @Override
             public void onDrawerClosed(View drawerView) {
                 super.onDrawerClosed(drawerView);
-                if (getCurrentFragment() instanceof MediaBrowserFragment)
-                    ((MediaBrowserFragment) getCurrentFragment()).setReadyToDisplay(true);
+                final Fragment current = getCurrentFragment();
+                if (current instanceof MediaBrowserFragment)
+                    ((MediaBrowserFragment) current).setReadyToDisplay(true);
             }
 
             // Hack to make navigation drawer browsable with DPAD.
@@ -179,26 +180,31 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
         // set a custom shadow that overlays the main content when the drawer opens
         mDrawerLayout.setDrawerShadow(R.drawable.drawer_shadow, GravityCompat.START);
 
-        if (getIntent().getBooleanExtra(StartActivity.EXTRA_UPGRADE, false)) {
-            /*
-             * The sliding menu is automatically opened when the user closes
-             * the info dialog. If (for any reason) the dialog is not shown,
-             * open the menu after a short delay.
-             */
-            new Handler().postDelayed(new Runnable() {
-                @Override
-                public void run() {
-                    mDrawerLayout.openDrawer(mNavigationView);
-                }
-            }, 500);
-        }
-
         /* Reload the latest preferences */
         mScanNeeded = savedInstanceState == null && mSettings.getBoolean("auto_rescan", true);
         mExtensionsManager = ExtensionsManager.getInstance();
         mMediaLibrary = VLCApplication.getMLInstance();
     }
 
+    private void restoreFragmentsStack(Bundle savedInstanceState, FragmentManager fm) {
+        final List<Fragment> fragments = fm.getFragments();
+        if (fragments != null) {
+            final FragmentTransaction ft =  fm.beginTransaction();
+            final Fragment displayed = fm.getFragment(savedInstanceState, "current_fragment_visible");
+            for (Fragment fragment : fragments)
+                if (fragment != null) {
+                    if (fragment instanceof ExtensionBrowser) {
+                        ft.remove(fragment);
+                    } else if ((fragment instanceof MediaBrowserFragment)) {
+                        mFragmentsStack.put(fragment.getTag(), new WeakReference<>(fragment));
+                        if (fragment != displayed)
+                            ft.hide(fragment);
+                    }
+                }
+            ft.commit();
+        }
+    }
+
     private void setupNavigationView() {
         mNavigationView = (NavigationView) findViewById(R.id.navigation);
         if (TextUtils.equals(BuildConfig.FLAVOR_target, "chrome")) {
@@ -313,8 +319,10 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
     protected void onSaveInstanceState(Bundle outState) {
         if (mCurrentFragment instanceof ExtensionBrowser)
             mCurrentFragment = null;
-        else
-            getSupportFragmentManager().putFragment(outState, "current_fragment", getCurrentFragment());
+        else {
+            getSupportFragmentManager().putFragment(outState, "current_fragment", mCurrentFragment);
+            getSupportFragmentManager().putFragment(outState, "current_fragment_visible", getCurrentFragment());
+        }
         super.onSaveInstanceState(outState);
         outState.putInt("current", mCurrentFragmentId);
     }
@@ -339,7 +347,7 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
             return;
 
         // If it's the directory view, a "backpressed" action shows a parent.
-        Fragment fragment = getCurrentFragment();
+        final Fragment fragment = getCurrentFragment();
         if (fragment instanceof BaseBrowserFragment){
             ((BaseBrowserFragment)fragment).goBack();
             return;
@@ -553,7 +561,7 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
     public boolean onQueryTextChange(String filterQueryString) {
         if (filterQueryString.length() < 3)
             return false;
-        Fragment current = getCurrentFragment();
+        final Fragment current = getCurrentFragment();
         if (current instanceof Filterable) {
             ((Filterable) current).getFilter().filter(filterQueryString);
             return true;
@@ -634,31 +642,26 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
     }
 
     public void showFragment(int id) {
-        FragmentManager fm = getSupportFragmentManager();
-        String tag = getTag(id);
+        final FragmentManager fm = getSupportFragmentManager();
+        final String tag = getTag(id);
         //Get new fragment
         Fragment fragment = null;
-        boolean add = false;
-        WeakReference<Fragment> wr = mFragmentsStack.get(tag);
-        if (wr != null)
-            fragment = wr.get();
-        if (fragment == null) {
+        final WeakReference<Fragment> wr = mFragmentsStack.get(tag);
+        final boolean add = wr == null || (fragment = wr.get()) == null;
+        if (add) {
             fragment = getNewFragment(id);
             mFragmentsStack.put(tag, new WeakReference<>(fragment));
-            add = true;
         }
         if (mCurrentFragment != null)
             if (mCurrentFragment instanceof ExtensionBrowser)
                 fm.beginTransaction().remove(mCurrentFragment).commit();
             else {
                 if (mCurrentFragment instanceof BaseBrowserFragment
-                        && !((BaseBrowserFragment) getCurrentFragment()).isRootDirectory()) {
-                    getSupportFragmentManager().popBackStackImmediate(getTag(id), FragmentManager.POP_BACK_STACK_INCLUSIVE);
-                    mCurrentFragment = getCurrentFragment();
-                }
+                        && !((BaseBrowserFragment) getCurrentFragment()).isRootDirectory())
+                    fm.popBackStackImmediate("root", FragmentManager.POP_BACK_STACK_INCLUSIVE);
                 fm.beginTransaction().hide(mCurrentFragment).commit();
             }
-        FragmentTransaction ft = fm.beginTransaction();
+        final FragmentTransaction ft = fm.beginTransaction();
         if (add)
             ft.add(R.id.fragment_placeholder, fragment, tag);
         else
@@ -670,12 +673,10 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
     }
 
     private void clearBackstackFromClass(Class clazz) {
-        FragmentManager fm = getSupportFragmentManager();
-        Fragment current = getCurrentFragment();
-        while (clazz.isInstance(current)) {
+        final FragmentManager fm = getSupportFragmentManager();
+        while (clazz.isInstance(getCurrentFragment())) {
             if (!fm.popBackStackImmediate())
                 break;
-            current = getCurrentFragment();
         }
     }
 
@@ -706,12 +707,14 @@ public class MainActivity extends ContentActivity implements FilterQueryProvider
     }
 
     private Fragment getFirstVisibleFragment() {
+        final Fragment frag = getSupportFragmentManager().findFragmentById(R.id.fragment_placeholder);
+        if (!frag.isHidden())
+            return frag;
         final List<Fragment> fragments = getSupportFragmentManager().getFragments();
-        if (fragments != null) {
+        if (fragments != null)
             for (Fragment fragment : fragments)
-                if (!fragment.isHidden() && fragment.getClass().isInstance(mCurrentFragment))
+                if (fragment != null && !fragment.isHidden() && fragment.getClass().isInstance(mCurrentFragment))
                     return fragment;
-        }
         return mCurrentFragment;
     }
 
