@@ -23,9 +23,6 @@
 
 package org.videolan.vlc.gui.dialogs;
 
-import android.os.Bundle;
-import android.support.v4.app.DialogFragment;
-
 import org.videolan.vlc.R;
 
 public class JumpToTimeDialog extends PickTimeFragment {
@@ -34,20 +31,8 @@ public class JumpToTimeDialog extends PickTimeFragment {
         super();
     }
 
-    public static JumpToTimeDialog newInstance(int theme) {
-        JumpToTimeDialog myFragment = new JumpToTimeDialog();
-
-        Bundle args = new Bundle();
-        args.putInt("theme", theme);
-        myFragment.setArguments(args);
-
-        return myFragment;
-    }
-
-    @Override
-    public void onCreate(Bundle savedInstanceState) {
-        super.onCreate(savedInstanceState);
-        setStyle(DialogFragment.STYLE_NO_FRAME, getArguments().getInt("theme"));
+    public static JumpToTimeDialog newInstance() {
+        return new JumpToTimeDialog();
     }
 
     protected void executeAction() {
