@@ -29,25 +29,23 @@ import android.content.Context;
 import android.content.Intent;
 import android.content.IntentFilter;
 import android.content.SharedPreferences;
-import android.net.ConnectivityManager;
-import android.net.NetworkInfo;
 import android.os.Build;
 import android.os.Bundle;
 import android.preference.PreferenceManager;
 import android.support.v4.content.LocalBroadcastManager;
-import android.text.TextUtils;
 import android.view.KeyEvent;
 
 import org.videolan.medialibrary.Medialibrary;
 import org.videolan.vlc.MediaParsingService;
+import org.videolan.vlc.ExternalMonitor;
 import org.videolan.vlc.VLCApplication;
-import org.videolan.vlc.gui.DialogActivity;
 import org.videolan.vlc.gui.PlaybackServiceActivity;
+import org.videolan.vlc.gui.helpers.UiTools;
 import org.videolan.vlc.gui.tv.SearchActivity;
 import org.videolan.vlc.util.Permissions;
 
 @TargetApi(Build.VERSION_CODES.JELLY_BEAN_MR1)
-public abstract class BaseTvActivity extends PlaybackServiceActivity {
+public abstract class BaseTvActivity extends PlaybackServiceActivity implements ExternalMonitor.NetworkObserver {
 
     private static final String TAG = "VLC/BaseTvActivity";
 
@@ -70,28 +68,25 @@ public abstract class BaseTvActivity extends PlaybackServiceActivity {
     protected void onStart() {
         super.onStart();
         mIsVisible = true;
-        //Handle network connection state
-        IntentFilter networkFilter = new IntentFilter(ConnectivityManager.CONNECTIVITY_ACTION);
+        ExternalMonitor.subscribeStorageCb(this);
 
-        IntentFilter storageFilter = new IntentFilter(Intent.ACTION_MEDIA_MOUNTED);
-        storageFilter.addAction(Intent.ACTION_MEDIA_REMOVED);
-        storageFilter.addAction(Intent.ACTION_MEDIA_EJECT);
-        storageFilter.addDataScheme("file");
-        IntentFilter parsingServiceFilter = new IntentFilter(MediaParsingService.ACTION_SERVICE_ENDED);
+        final IntentFilter parsingServiceFilter = new IntentFilter(MediaParsingService.ACTION_SERVICE_ENDED);
         parsingServiceFilter.addAction(MediaParsingService.ACTION_SERVICE_STARTED);
+        parsingServiceFilter.addAction(MediaParsingService.ACTION_PROGRESS);
+        parsingServiceFilter.addAction(MediaParsingService.ACTION_NEW_STORAGE);
 
         mRegistering = true;
         LocalBroadcastManager.getInstance(this).registerReceiver(mParsingServiceReceiver, parsingServiceFilter);
-        registerReceiver(mExternalDevicesReceiver, storageFilter);
-        registerReceiver(mExternalDevicesReceiver, networkFilter);
+        ExternalMonitor.subscribeNetworkCb(this);
     }
 
     @Override
     protected void onStop() {
         mIsVisible = false;
+        ExternalMonitor.unsubscribeStorageCb(this);
         super.onStop();
-        unregisterReceiver(mExternalDevicesReceiver);
         LocalBroadcastManager.getInstance(this).unregisterReceiver(mParsingServiceReceiver);
+        ExternalMonitor.unsubscribeNetworkCb(this);
     }
 
     @Override
@@ -104,7 +99,7 @@ public abstract class BaseTvActivity extends PlaybackServiceActivity {
     }
 
     protected abstract void refresh();
-    protected abstract void onNetworkUpdated();
+    public void onNetworkConnectionChanged(boolean connected) {}
 
     protected final BroadcastReceiver mParsingServiceReceiver = new BroadcastReceiver() {
 
@@ -118,6 +113,12 @@ public abstract class BaseTvActivity extends PlaybackServiceActivity {
                 case MediaParsingService.ACTION_SERVICE_STARTED:
                     onParsingServiceStarted();
                     break;
+                case MediaParsingService.ACTION_PROGRESS:
+                    onParsingServiceProgress();
+                    break;
+                case MediaParsingService.ACTION_NEW_STORAGE:
+                    UiTools.newStorageDetected(BaseTvActivity.this, intent.getStringExtra(MediaParsingService.EXTRA_PATH));
+                    break;
             }
         }
     };
@@ -127,39 +128,6 @@ public abstract class BaseTvActivity extends PlaybackServiceActivity {
     }
 
     protected void onParsingServiceStarted() {}
+    protected void onParsingServiceProgress() {}
     protected void onParsingServiceFinished() {}
-
-    protected final BroadcastReceiver mExternalDevicesReceiver = new BroadcastReceiver() {
-        @Override
-        public void onReceive(Context context, Intent intent) {
-            if (mRegistering) {
-                mRegistering = false;
-                return;
-            }
-            String action = intent.getAction();
-            if (ConnectivityManager.CONNECTIVITY_ACTION.equals(action)) {
-                final NetworkInfo networkInfo = ((ConnectivityManager) getApplicationContext().getSystemService(
-                        Context.CONNECTIVITY_SERVICE)).getActiveNetworkInfo();
-                if (networkInfo != null && networkInfo.getState() == NetworkInfo.State.CONNECTED)
-                    onNetworkUpdated();
-            } else if (action.equalsIgnoreCase(Intent.ACTION_MEDIA_MOUNTED)) {
-                String path = intent.getData().getPath();
-                String uuid = intent.getData().getLastPathSegment();
-                if (TextUtils.isEmpty(uuid))
-                    return;
-                boolean isIgnored = mSettings.getBoolean("ignore_"+ uuid, false);
-                if (!isIgnored && mMediaLibrary.addDevice(uuid, path, true, true)) {
-                    startActivity(new Intent(BaseTvActivity.this, DialogActivity.class)
-                            .setAction(DialogActivity.KEY_STORAGE)
-                            .addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
-                            .putExtra(MediaParsingService.EXTRA_PATH, path));
-                } else
-                    startService(new Intent(MediaParsingService.ACTION_RELOAD, null, BaseTvActivity.this, MediaParsingService.class)
-                            .putExtra(MediaParsingService.EXTRA_PATH, path));
-            } else if (action.equalsIgnoreCase(Intent.ACTION_MEDIA_EJECT) || action.equalsIgnoreCase(Intent.ACTION_MEDIA_REMOVED)) {
-                mMediaLibrary.removeDevice(intent.getData().getLastPathSegment());
-                onParsingServiceFinished();
-            }
-        }
-    };
 }
